"""
Main interface for mwaa service type definitions.

Usage::

    ```python
    from mypy_boto3_mwaa.type_defs import DimensionTypeDef

    data: DimensionTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import Any, Dict, List

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "DimensionTypeDef",
    "EnvironmentTypeDef",
    "LastUpdateTypeDef",
    "LoggingConfigurationTypeDef",
    "ModuleLoggingConfigurationInputTypeDef",
    "ModuleLoggingConfigurationTypeDef",
    "NetworkConfigurationTypeDef",
    "ResponseMetadata",
    "StatisticSetTypeDef",
    "UpdateErrorTypeDef",
    "CreateCliTokenResponseTypeDef",
    "CreateEnvironmentOutputTypeDef",
    "CreateWebLoginTokenResponseTypeDef",
    "GetEnvironmentOutputTypeDef",
    "ListEnvironmentsOutputTypeDef",
    "ListTagsForResourceOutputTypeDef",
    "LoggingConfigurationInputTypeDef",
    "MetricDatumTypeDef",
    "PaginatorConfigTypeDef",
    "UpdateEnvironmentOutputTypeDef",
    "UpdateNetworkConfigurationInputTypeDef",
)

DimensionTypeDef = TypedDict("DimensionTypeDef", {"Name": str, "Value": str})

EnvironmentTypeDef = TypedDict(
    "EnvironmentTypeDef",
    {
        "AirflowConfigurationOptions": Dict[str, str],
        "AirflowVersion": str,
        "Arn": str,
        "CreatedAt": datetime,
        "DagS3Path": str,
        "EnvironmentClass": str,
        "ExecutionRoleArn": str,
        "KmsKey": str,
        "LastUpdate": "LastUpdateTypeDef",
        "LoggingConfiguration": "LoggingConfigurationTypeDef",
        "MaxWorkers": int,
        "Name": str,
        "NetworkConfiguration": "NetworkConfigurationTypeDef",
        "PluginsS3ObjectVersion": str,
        "PluginsS3Path": str,
        "RequirementsS3ObjectVersion": str,
        "RequirementsS3Path": str,
        "ServiceRoleArn": str,
        "SourceBucketArn": str,
        "Status": Literal[
            "CREATING", "CREATE_FAILED", "AVAILABLE", "UPDATING", "DELETING", "DELETED"
        ],
        "Tags": Dict[str, str],
        "WebserverAccessMode": Literal["PRIVATE_ONLY", "PUBLIC_ONLY"],
        "WebserverUrl": str,
        "WeeklyMaintenanceWindowStart": str,
    },
    total=False,
)

LastUpdateTypeDef = TypedDict(
    "LastUpdateTypeDef",
    {
        "CreatedAt": datetime,
        "Error": "UpdateErrorTypeDef",
        "Status": Literal["SUCCESS", "PENDING", "FAILED"],
    },
    total=False,
)

LoggingConfigurationTypeDef = TypedDict(
    "LoggingConfigurationTypeDef",
    {
        "DagProcessingLogs": "ModuleLoggingConfigurationTypeDef",
        "SchedulerLogs": "ModuleLoggingConfigurationTypeDef",
        "TaskLogs": "ModuleLoggingConfigurationTypeDef",
        "WebserverLogs": "ModuleLoggingConfigurationTypeDef",
        "WorkerLogs": "ModuleLoggingConfigurationTypeDef",
    },
    total=False,
)

ModuleLoggingConfigurationInputTypeDef = TypedDict(
    "ModuleLoggingConfigurationInputTypeDef",
    {"Enabled": bool, "LogLevel": Literal["CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG"]},
)

ModuleLoggingConfigurationTypeDef = TypedDict(
    "ModuleLoggingConfigurationTypeDef",
    {
        "CloudWatchLogGroupArn": str,
        "Enabled": bool,
        "LogLevel": Literal["CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG"],
    },
    total=False,
)

NetworkConfigurationTypeDef = TypedDict(
    "NetworkConfigurationTypeDef",
    {"SecurityGroupIds": List[str], "SubnetIds": List[str]},
    total=False,
)

ResponseMetadata = TypedDict(
    "ResponseMetadata",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, Any],
        "RetryAttempts": int,
    },
)

StatisticSetTypeDef = TypedDict(
    "StatisticSetTypeDef",
    {"Maximum": float, "Minimum": float, "SampleCount": int, "Sum": float},
    total=False,
)

UpdateErrorTypeDef = TypedDict(
    "UpdateErrorTypeDef", {"ErrorCode": str, "ErrorMessage": str}, total=False
)

CreateCliTokenResponseTypeDef = TypedDict(
    "CreateCliTokenResponseTypeDef", {"CliToken": str, "WebServerHostname": str}, total=False
)

CreateEnvironmentOutputTypeDef = TypedDict(
    "CreateEnvironmentOutputTypeDef",
    {"Arn": str, "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

CreateWebLoginTokenResponseTypeDef = TypedDict(
    "CreateWebLoginTokenResponseTypeDef", {"WebServerHostname": str, "WebToken": str}, total=False
)

GetEnvironmentOutputTypeDef = TypedDict(
    "GetEnvironmentOutputTypeDef",
    {"Environment": "EnvironmentTypeDef", "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

_RequiredListEnvironmentsOutputTypeDef = TypedDict(
    "_RequiredListEnvironmentsOutputTypeDef", {"Environments": List[str]}
)
_OptionalListEnvironmentsOutputTypeDef = TypedDict(
    "_OptionalListEnvironmentsOutputTypeDef",
    {"NextToken": str, "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

class ListEnvironmentsOutputTypeDef(
    _RequiredListEnvironmentsOutputTypeDef, _OptionalListEnvironmentsOutputTypeDef
):
    pass

ListTagsForResourceOutputTypeDef = TypedDict(
    "ListTagsForResourceOutputTypeDef",
    {"Tags": Dict[str, str], "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

LoggingConfigurationInputTypeDef = TypedDict(
    "LoggingConfigurationInputTypeDef",
    {
        "DagProcessingLogs": "ModuleLoggingConfigurationInputTypeDef",
        "SchedulerLogs": "ModuleLoggingConfigurationInputTypeDef",
        "TaskLogs": "ModuleLoggingConfigurationInputTypeDef",
        "WebserverLogs": "ModuleLoggingConfigurationInputTypeDef",
        "WorkerLogs": "ModuleLoggingConfigurationInputTypeDef",
    },
    total=False,
)

_RequiredMetricDatumTypeDef = TypedDict(
    "_RequiredMetricDatumTypeDef", {"MetricName": str, "Timestamp": datetime}
)
_OptionalMetricDatumTypeDef = TypedDict(
    "_OptionalMetricDatumTypeDef",
    {
        "Dimensions": List["DimensionTypeDef"],
        "StatisticValues": "StatisticSetTypeDef",
        "Unit": Literal[
            "Seconds",
            "Microseconds",
            "Milliseconds",
            "Bytes",
            "Kilobytes",
            "Megabytes",
            "Gigabytes",
            "Terabytes",
            "Bits",
            "Kilobits",
            "Megabits",
            "Gigabits",
            "Terabits",
            "Percent",
            "Count",
            "Bytes/Second",
            "Kilobytes/Second",
            "Megabytes/Second",
            "Gigabytes/Second",
            "Terabytes/Second",
            "Bits/Second",
            "Kilobits/Second",
            "Megabits/Second",
            "Gigabits/Second",
            "Terabits/Second",
            "Count/Second",
            "None",
        ],
        "Value": float,
    },
    total=False,
)

class MetricDatumTypeDef(_RequiredMetricDatumTypeDef, _OptionalMetricDatumTypeDef):
    pass

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
)

UpdateEnvironmentOutputTypeDef = TypedDict(
    "UpdateEnvironmentOutputTypeDef",
    {"Arn": str, "ResponseMetadata": "ResponseMetadata"},
    total=False,
)

UpdateNetworkConfigurationInputTypeDef = TypedDict(
    "UpdateNetworkConfigurationInputTypeDef", {"SecurityGroupIds": List[str]}
)



"""
Main interface for mwaa service.

Usage::

    ```python
    import boto3
    from mypy_boto3_mwaa import (
        Client,
        ListEnvironmentsPaginator,
        MWAAClient,
    )

    session = boto3.Session()

    client: MWAAClient = boto3.client("mwaa")
    session_client: MWAAClient = session.client("mwaa")

    list_environments_paginator: ListEnvironmentsPaginator = client.get_paginator("list_environments")
    ```
"""
from mypy_boto3_mwaa.client import MWAAClient
from mypy_boto3_mwaa.paginator import ListEnvironmentsPaginator

Client = MWAAClient


__all__ = ("Client", "ListEnvironmentsPaginator", "MWAAClient")



"""
Main interface for mwaa service client

Usage::

    ```python
    import boto3
    from mypy_boto3_mwaa import MWAAClient

    client: MWAAClient = boto3.client("mwaa")
    ```
"""
import sys
from typing import Any, Dict, List, Type

from botocore.client import ClientMeta

from mypy_boto3_mwaa.paginator import ListEnvironmentsPaginator
from mypy_boto3_mwaa.type_defs import (
    CreateCliTokenResponseTypeDef,
    CreateEnvironmentOutputTypeDef,
    CreateWebLoginTokenResponseTypeDef,
    GetEnvironmentOutputTypeDef,
    ListEnvironmentsOutputTypeDef,
    ListTagsForResourceOutputTypeDef,
    LoggingConfigurationInputTypeDef,
    MetricDatumTypeDef,
    NetworkConfigurationTypeDef,
    UpdateEnvironmentOutputTypeDef,
    UpdateNetworkConfigurationInputTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("MWAAClient",)


class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str

    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str


class Exceptions:
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]


class MWAAClient:
    """
    [MWAA.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client)
    """

    meta: ClientMeta
    exceptions: Exceptions

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.can_paginate)
        """

    def create_cli_token(self, Name: str) -> CreateCliTokenResponseTypeDef:
        """
        [Client.create_cli_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.create_cli_token)
        """

    def create_environment(
        self,
        DagS3Path: str,
        ExecutionRoleArn: str,
        Name: str,
        NetworkConfiguration: "NetworkConfigurationTypeDef",
        SourceBucketArn: str,
        AirflowConfigurationOptions: Dict[str, str] = None,
        AirflowVersion: str = None,
        EnvironmentClass: str = None,
        KmsKey: str = None,
        LoggingConfiguration: LoggingConfigurationInputTypeDef = None,
        MaxWorkers: int = None,
        PluginsS3ObjectVersion: str = None,
        PluginsS3Path: str = None,
        RequirementsS3ObjectVersion: str = None,
        RequirementsS3Path: str = None,
        Tags: Dict[str, str] = None,
        WebserverAccessMode: Literal["PRIVATE_ONLY", "PUBLIC_ONLY"] = None,
        WeeklyMaintenanceWindowStart: str = None,
    ) -> CreateEnvironmentOutputTypeDef:
        """
        [Client.create_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.create_environment)
        """

    def create_web_login_token(self, Name: str) -> CreateWebLoginTokenResponseTypeDef:
        """
        [Client.create_web_login_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.create_web_login_token)
        """

    def delete_environment(self, Name: str) -> Dict[str, Any]:
        """
        [Client.delete_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.delete_environment)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.generate_presigned_url)
        """

    def get_environment(self, Name: str) -> GetEnvironmentOutputTypeDef:
        """
        [Client.get_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.get_environment)
        """

    def list_environments(
        self, MaxResults: int = None, NextToken: str = None
    ) -> ListEnvironmentsOutputTypeDef:
        """
        [Client.list_environments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.list_environments)
        """

    def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceOutputTypeDef:
        """
        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.list_tags_for_resource)
        """

    def publish_metrics(
        self, EnvironmentName: str, MetricData: List[MetricDatumTypeDef]
    ) -> Dict[str, Any]:
        """
        [Client.publish_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.publish_metrics)
        """

    def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
        """
        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.tag_resource)
        """

    def untag_resource(self, ResourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
        """
        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.untag_resource)
        """

    def update_environment(
        self,
        Name: str,
        AirflowConfigurationOptions: Dict[str, str] = None,
        AirflowVersion: str = None,
        DagS3Path: str = None,
        EnvironmentClass: str = None,
        ExecutionRoleArn: str = None,
        LoggingConfiguration: LoggingConfigurationInputTypeDef = None,
        MaxWorkers: int = None,
        NetworkConfiguration: UpdateNetworkConfigurationInputTypeDef = None,
        PluginsS3ObjectVersion: str = None,
        PluginsS3Path: str = None,
        RequirementsS3ObjectVersion: str = None,
        RequirementsS3Path: str = None,
        SourceBucketArn: str = None,
        WebserverAccessMode: Literal["PRIVATE_ONLY", "PUBLIC_ONLY"] = None,
        WeeklyMaintenanceWindowStart: str = None,
    ) -> UpdateEnvironmentOutputTypeDef:
        """
        [Client.update_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Client.update_environment)
        """

    def get_paginator(
        self, operation_name: Literal["list_environments"]
    ) -> ListEnvironmentsPaginator:
        """
        [Paginator.ListEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Paginator.ListEnvironments)
        """



"""
Main interface for mwaa service client paginators.

Usage::

    ```python
    import boto3

    from mypy_boto3_mwaa import MWAAClient
    from mypy_boto3_mwaa.paginator import (
        ListEnvironmentsPaginator,
    )

    client: MWAAClient = boto3.client("mwaa")

    list_environments_paginator: ListEnvironmentsPaginator = client.get_paginator("list_environments")
    ```
"""
from typing import Iterator

from botocore.paginate import Paginator as Boto3Paginator

from mypy_boto3_mwaa.type_defs import ListEnvironmentsOutputTypeDef, PaginatorConfigTypeDef

__all__ = ("ListEnvironmentsPaginator",)

class ListEnvironmentsPaginator(Boto3Paginator):
    """
    [Paginator.ListEnvironments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Paginator.ListEnvironments)
    """

    def paginate(
        self, PaginationConfig: PaginatorConfigTypeDef = None
    ) -> Iterator[ListEnvironmentsOutputTypeDef]:
        """
        [ListEnvironments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.13/reference/services/mwaa.html#MWAA.Paginator.ListEnvironments.paginate)
        """
